@@ -544,7 +544,8 @@ class SQLAnywhereConnector(DatabaseConnector):
             self.config_parser.print_log_message('ERROR', e)
             raise
 
-    def convert_view_code(self, view_code: str, settings: dict):
+    def convert_view_code(self, settings: dict):
+        view_code = settings['view_code']
         return view_code
 
     def get_sequence_current_value(self, sequence_id: int):
@@ -628,9 +629,59 @@ class SQLAnywhereConnector(DatabaseConnector):
 
         return { 'table_description': output.strip() }
 
-
     def testing_select(self):
         return "SELECT 1"
 
+    def get_database_version(self):
+        try:
+            self.connect()
+            cursor = self.connection.cursor()
+            cursor.execute("select top 1 version, platform, first_time from SYSHISTORY order by first_time desc")
+            version = cursor.fetchone()
+            cursor.close()
+            self.disconnect()
+            return version
+        except Exception as e:
+            self.config_parser.print_log_message('ERROR', f"Error fetching database version: {e}")
+            raise
+
+    def get_database_size(self):
+        query = "select round(db_property('FileSize') * db_property('PageSize') / 1024 / 1024,2) as db_size_mb"
+        self.connect()
+        cursor = self.connection.cursor()
+        cursor.execute(query)
+        size = cursor.fetchone()[0]
+        cursor.close()
+        self.disconnect()
+        return size
+
+    def get_top10_biggest_tables(self, settings):
+        query = f"""
+            SELECT TOP 10
+                t.table_name,
+                table_page_count
+            FROM sys.systable t
+            WHERE creator in (SELECT DISTINCT user_id
+            FROM sys.SYSUSERPERM where user_name = '{settings.get('source_schema', 'public')}')
+            ORDER BY table_page_count DESC
+        """
+        try:
+            self.connect()
+            cursor = self.connection.cursor()
+            cursor.execute(query)
+            tables = []
+            for row in cursor.fetchall():
+                tables.append({
+                    'table_name': row[0],
+                    'table_size_pages': row[1]
+                })
+            cursor.close()
+            self.disconnect()
+            return tables
+        except Exception as e:
+            self.config_parser.print_log_message('ERROR', f"Error executing query: {query}")
+            self.config_parser.print_log_message('ERROR', e)
+            raise
+
 if __name__ == "__main__":
     print("This script is not meant to be run directly")
